#[non_exhaustive]pub struct BucketInfo {
pub buckets: Option<Vec<Bucket>>,
}Expand description
A container for the calculated facet values and counts.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.buckets: Option<Vec<Bucket>>A list of the calculated facet values and counts.
Implementations
Sourceimpl BucketInfo
impl BucketInfo
Sourceimpl BucketInfo
impl BucketInfo
Sourcepub fn builder() -> BucketInfoBuilder
pub fn builder() -> BucketInfoBuilder
Creates a new builder-style object to manufacture BucketInfo.