#[non_exhaustive]pub struct FieldStats {
pub min: Option<String>,
pub max: Option<String>,
pub count: i64,
pub missing: i64,
pub sum: f64,
pub sum_of_squares: f64,
pub mean: Option<String>,
pub stddev: f64,
}Expand description
The statistics for a field calculated in the request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.min: Option<String>The minimum value found in the specified field in the result set.
If the field is numeric (int, int-array, double, or double-array), min is the string representation of a double-precision 64-bit floating point value. If the field is date or date-array, min is the string representation of a date with the format specified in IETF RFC3339: yyyy-mm-ddTHH:mm:ss.SSSZ.
max: Option<String>The maximum value found in the specified field in the result set.
If the field is numeric (int, int-array, double, or double-array), max is the string representation of a double-precision 64-bit floating point value. If the field is date or date-array, max is the string representation of a date with the format specified in IETF RFC3339: yyyy-mm-ddTHH:mm:ss.SSSZ.
count: i64The number of documents that contain a value in the specified field in the result set.
missing: i64The number of documents that do not contain a value in the specified field in the result set.
sum: f64The sum of the field values across the documents in the result set. null for date fields.
sum_of_squares: f64The sum of all field values in the result set squared.
mean: Option<String>The average of the values found in the specified field in the result set.
If the field is numeric (int, int-array, double, or double-array), mean is the string representation of a double-precision 64-bit floating point value. If the field is date or date-array, mean is the string representation of a date with the format specified in IETF RFC3339: yyyy-mm-ddTHH:mm:ss.SSSZ.
stddev: f64The standard deviation of the values in the specified field in the result set.
Implementations
Sourceimpl FieldStats
impl FieldStats
Sourcepub fn min(&self) -> Option<&str>
pub fn min(&self) -> Option<&str>
The minimum value found in the specified field in the result set.
If the field is numeric (int, int-array, double, or double-array), min is the string representation of a double-precision 64-bit floating point value. If the field is date or date-array, min is the string representation of a date with the format specified in IETF RFC3339: yyyy-mm-ddTHH:mm:ss.SSSZ.
Sourcepub fn max(&self) -> Option<&str>
pub fn max(&self) -> Option<&str>
The maximum value found in the specified field in the result set.
If the field is numeric (int, int-array, double, or double-array), max is the string representation of a double-precision 64-bit floating point value. If the field is date or date-array, max is the string representation of a date with the format specified in IETF RFC3339: yyyy-mm-ddTHH:mm:ss.SSSZ.
Sourcepub fn count(&self) -> i64
pub fn count(&self) -> i64
The number of documents that contain a value in the specified field in the result set.
Sourcepub fn missing(&self) -> i64
pub fn missing(&self) -> i64
The number of documents that do not contain a value in the specified field in the result set.
Sourcepub fn sum(&self) -> f64
pub fn sum(&self) -> f64
The sum of the field values across the documents in the result set. null for date fields.
Sourcepub fn sum_of_squares(&self) -> f64
pub fn sum_of_squares(&self) -> f64
The sum of all field values in the result set squared.
Sourcepub fn mean(&self) -> Option<&str>
pub fn mean(&self) -> Option<&str>
The average of the values found in the specified field in the result set.
If the field is numeric (int, int-array, double, or double-array), mean is the string representation of a double-precision 64-bit floating point value. If the field is date or date-array, mean is the string representation of a date with the format specified in IETF RFC3339: yyyy-mm-ddTHH:mm:ss.SSSZ.
Sourceimpl FieldStats
impl FieldStats
Sourcepub fn builder() -> FieldStatsBuilder
pub fn builder() -> FieldStatsBuilder
Creates a new builder-style object to manufacture FieldStats.